@@ -1,5 +1,3 @@
-
-
 #: The vortex name for the Server service
 peekServerName = "peek-server"
 
@@ -12,8 +10,11 @@ peekAgentName = "peek-agent"
 #: The vortex name for the Worker service
 peekWorkerName = "peek-worker"
 
-# #: The vortex name for the Mobile service
-# peekWorkerName = "peek-mobile"
-#
-# #: The vortex name for the Admin service
-# peekWorkerName = "peek-admin"
\ No newline at end of file
+#: The vortex name for the Mobile device/browser clients
+peekMobileName = "peek-mobile"
+
+#: The vortex name for the Desktop browser clients
+peekDesktopName = "peek-desktop"
+
+#: The vortex name for the Admin browser client
+peekAdminName = "peek-admin"
